@@ -5,10 +5,13 @@ from flufl.i18n._expand import expand
 from flufl.i18n._registry import registry
 from flufl.i18n._strategy import PackageStrategy, SimpleStrategy
 from flufl.i18n.types import (
-    RuntimeTranslator, TranslationContextManager, TranslationStrategy)
+    RuntimeTranslator,
+    TranslationContextManager,
+    TranslationStrategy,
+)
 
 
-__version__ = '3.1.4'
+__version__ = '3.1.5'
 
 
 _public(
@@ -20,7 +23,7 @@ _public(
     TranslationStrategy=TranslationStrategy,
     expand=expand,
     registry=registry,
-    )
+)
 
 
 @_public
